<!DOCTYPE html>
<html>

<head>
    {% block head %}
    <title>{% block title %}{% endblock %} - RAMP</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- Fonts -->
    <link href='https://fonts.googleapis.com/css?family=Roboto+Condensed:300,400' rel='stylesheet' type='text/css'>
    <link href='https://fonts.googleapis.com/css?family=Lato:300,400,700,900' rel='stylesheet' type='text/css'>
    <!-- CSS Libs -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/bootstrap.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/font-awesome.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/animate.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/bootstrap-switch.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/checkbox3.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/jquery.dataTables.min.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/dataTables.bootstrap.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='lib/css/select2.min.css') }}">
    <!-- CSS App -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/themes/flat-blue.css') }}">
    {% endblock %}
</head>

<body class="flat-blue" {% block bodyoptions %}{% endblock %}>

  <div class="card" id="page-container">
    <div id=event-container>
      <div class="card-header">
      </div>
      <div class="card-body">
        <ul>
          <li class="rules">Submissions will open at (UTC) {{ event.opening_timestamp }}
          <li class="rules">When you submit, your submission is sent to be trained automatically. The jobs may wait some time in a queue before being run so be patient.</li>
          <li class="rules">Pending (untrained) and failing submissions can be resubmitted under the same name at an arbitrary frequency.</li>
          <li class="rules">Once your submission is trained, it cannot be deleted or replaced.</li>
          <li class="rules">After each succesfully trained submission, you have to wait {{ event.min_duration_between_submissions }}s to resubmit. </li>
          <li class="rules">The leaderboard is in "hidden" mode until (UTC) {{ event.public_opening_timestamp }} which means that all scores are visible, but the links pointing to the code of the participants are hidden. After (UTC) {{ event.public_opening_timestamp }}, all submitted codes are public. <b>You will be encouraged to look at and reuse each other's code.</b>
        </ul>
      </div>
    </div>
  </div>
</div>

<div>
  <!-- Javascript Libs -->
  <script type="text/javascript">parent.AdjustIframeHeight(document.getElementById("page-container").scrollHeight);</script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/bootstrap.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/Chart.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/bootstrap-switch.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.matchHeight-min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/jquery.dataTables.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/dataTables.bootstrap.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/select2.full.min.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/ace.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/mode-html.js') }}"></script>
  <script type="text/javascript" src="{{ url_for('static', filename='lib/js/ace/theme-github.js') }}"></script>
  <!-- Javascript -->
  <script type="text/javascript" src="{{ url_for('static', filename='js/app.js') }}"></script>
  {#            <script type="text/javascript" src="{{ url_for('static', filename='js/index.js') }}"></script> #}

</body>