{% extends "base.html" %}

{% block content %}
<div class="col-xs-12">
     <div class="card">
         <div class="card-body">
             <p> Enter your email below. If you are a registered user, we are going to send you a link to reset your password. </p>
             <form class="ui form" action="" method="POST" name="reset_password">
                 {{ form.csrf_token }}
                 {{ form.email.label }}: {{ form.email }}<br>
                 <input type="submit" value="Change my password" class="ui submit button">
             </form>
             <p><font color="red">{{ error }}</font></p>
		</div>
	</div>
</div>
{% endblock %}
