{% extends "base.html" %}

{% block head %}
    {{ super() }}
    <script src="https://cdn.rawgit.com/google/code-prettify/master/loader/run_prettify.js?skin=sunburst"></script>
{% endblock %}

{% block title %}Submission code - Error{% endblock %}

{% block content %}


<div class="col-xs-12">
  <div class="card">
    <div class="card-header">
      <div class="card-title">
          <div class="title">
              <a href="/events/{{ event.name }}/leaderboard"><i class="icon fa fa-flag"></i> Leaderboard</a>
            <span><i class="icon fa fa-angle-right"></i></span>
            {{ event.name }} 
            <span><i class="icon fa fa-angle-right"></i></span>
            {{ team.name }} 
            <span><i class="icon fa fa-angle-right"></i></span>
            {{ submission.name }} 
            <span><i class="icon fa fa-angle-right"></i></span>
            {{ submission.state }} 
          </div>
      </div>
    </div>
    <div class="card-body">
        <pre class="prettyprint linenums">{{ submission.error_msg }}</pre>
	</div>
  </div>
</div>
{% endblock %}

