{% extends "base.html" %}

{% block content %}
<div class="col-xs-12">
     <div class="card">
         <div class="card-body">
           <form action="{{ url_for('auth.reset_with_token', token=token) }}" method="POST">
               {{ form.password.label }}: {{ form.password }}<br>
               {{ form.csrf_token }}
               <input type="submit" value="Change my password" />
           </form>
		</div>
    </div>
</div>
{% endblock %}
